coherence.upnp.services.clients.rendering_control_client (module) — Cohen3 0.8.0 documentation

# coherence.upnp.services.clients.rendering_control_client (module)

class `RenderingControlClient`(service)

  Bases: `object`

  `remove`()
  `subscribe_for_variable`(var_name, callback, signal=False)
  `list_presets`(instance_id=0)
  `select_presets`(instance_id=0, preset_name='')
  `get_mute`(instance_id=0, channel='Master')
  `set_mute`(instance_id=0, channel='Master', desired_mute=0)
  `get_volume`(instance_id=0, channel='Master')
  `set_volume`(instance_id=0, channel='Master', desired_volume=0)
  `get_volume_db`(instance_id=0, channel='Master')
  `set_volume_db`(instance_id=0, channel='Master', desired_volume=0)
  `get_volume_db_range`(instance_id=0, channel='Master')
  `get_loudness`(instance_id=0, channel='Master')
  `set_loudness`(instance_id=0, channel='Master', desired_loudness=0)